"use strict";

chrome.runtime.onInstalled.addListener(function() {
    localStorage.clear();

    chrome.tabs.query({
        url: "*://*/*"
    }, function(tabs) {
        tabs.forEach(function(tab) {
            if(tab.id>0) {
                chrome.tabs.executeScript(tab.id, {
                    file: "content_script.js", allFrames: true
                }, function(result) {
                    if(typeof result === "undefined") {
                        // ...
                    }
                });
            }
        });
    });
});

chrome.runtime.onMessage.addListener(function(message, sender) {
    if(message.method === "openLocalFile") {
        const localFileUrl = message.localFileUrl;
        const tab = sender.tab;
        openLocalFile(localFileUrl, tab);
    }
});


const openLocalFile = function(localFileUrl, baseTab) {
    chrome.tabs.create({
        url: localFileUrl, index: baseTab.index + 1
    });
};

function fileCallback() {
    getCurrentTabUrl(function(url) {
        if(url) {
            var origin = new URL(url);
            if(origin.hostname.indexOf("o-i-b.com")>=0 || origin.hostname.indexOf("ops-in-a-box")>=0) {
                var script = 'var className="oibFileAddonInstalled";if(document.body.className.indexOf(className)==-1)document.body.className+=" "+className;';

                chrome.tabs.executeScript({
                    code: script
                });
            }
        }
    });
}

chrome.tabs.onActivated.addListener(fileCallback);
chrome.tabs.onUpdated.addListener(fileCallback);
chrome.tabs.onCreated.addListener(fileCallback);

function getCurrentTabUrl(callback) {
    var queryInfo = {
        active: true, currentWindow: true
    };

    chrome.tabs.query(queryInfo, function(tabs) {
        var tab = tabs[0]||{};

        var url = tab.url;

        callback(url);
    });
}

function callback() {
    getCurrentTabUrl(function(url) {
        if(url) {
            var origin = new URL(url);
            if(origin.hostname.indexOf("o-i-b.com")>=0 || origin.hostname.indexOf("ops-in-a-box")>=0) {
                var script = 'var className="oibAddonInstalled";if(document.body.className.indexOf(className)==-1)document.body.className+=" "+className;';

                chrome.tabs.executeScript({
                    code: script
                });
            }
        }
    });
}

chrome.tabs.onActivated.addListener(callback);
chrome.tabs.onUpdated.addListener(callback);
chrome.tabs.onCreated.addListener(callback);